# Contributing to Eclipse Thingweb

Thanks for your interest in this project. General information
regarding source code management, builds, coding standards, and
more can be found here:

-   https://projects.eclipse.org/projects/iot.thingweb/developer

## Legal Requirements

Thingweb is an [Eclipse IoT](https://iot.eclipse.org) project and as such is governed by the Eclipse Development process.
This process helps us in creating great open source software within a safe legal framework.

Thus, before your contribution can be accepted by the project team, contributors must electronically sign the [Eclipse Contributor Agreement (ECA)](http://www.eclipse.org/legal/ECA.php) and follow these preliminary steps:

-   Obtain an [Eclipse Foundation account](https://accounts.eclipse.org/)
    -   Anyone who currently uses Eclipse Bugzilla or Gerrit systems already has one of those
    -   Newcomers can [create a new account](https://accounts.eclipse.org/user/register?destination=user)
-   Add your GiHub username to your Eclipse Foundation account
    -   ([Log into Eclipse](https://accounts.eclipse.org/))
    -   Go to the _Edit Profile_ tab
    -   Fill in the _GitHub ID_ under _Social Media Links_ and save
-   Sign the [Eclipse Contributor Agreement](http://www.eclipse.org/legal/ECA.php)
    -   ([Log into Eclipse](https://accounts.eclipse.org/))
    -   If the _Status_ entry _Eclipse Contributor Agreement_ has a green checkmark, the ECA is already signed
    -   If not, go to the _Eclipse Contributor Agreement_ tab or follow the corresponding link under _Status_
    -   Fill out the form and sign it electronically
-   Sign-off every commit using the same email address used for your Eclipse account
    -   Set the Git user email address with `git config user.email "<your Eclipse account email>"`
    -   Add the `-s` flag when you make the commit(s), e.g. `git commit -s -m "feat: add support for magic"`
-   Open a [Pull Request](https://github.com/eclipse-thingweb/node-wot/pulls)

For more information, please see the Eclipse Committer Handbook:
https://www.eclipse.org/projects/handbook/#resources-commit

## Contact

Contact the project developers via the project's "dev" list.

-   https://dev.eclipse.org/mailman/listinfo/thingweb-dev
